Class: Google::Cloud::DeviceStreaming::V1::DeviceMessage

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/devicestreaming/v1/adb_service.rb

Overview

A message returned from a device.

Instance Attribute Summary collapse

Instance Attribute Details

#status_update::Google::Cloud::DeviceStreaming::V1::StatusUpdate

Returns Information about the device's state.

Note: The following fields are mutually exclusive: status_update, stream_status, stream_data. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DeviceStreaming::V1::StatusUpdate)

    Information about the device's state.

    Note: The following fields are mutually exclusive: status_update, stream_status, stream_data. If a field in that set is populated, all other fields in the set will automatically be cleared.



40
41
42
43
# File 'proto_docs/google/cloud/devicestreaming/v1/adb_service.rb', line 40

class DeviceMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#stream_data::Google::Cloud::DeviceStreaming::V1::StreamData

Returns Data from an open stream.

Note: The following fields are mutually exclusive: stream_data, status_update, stream_status. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DeviceStreaming::V1::StreamData)

    Data from an open stream.

    Note: The following fields are mutually exclusive: stream_data, status_update, stream_status. If a field in that set is populated, all other fields in the set will automatically be cleared.



40
41
42
43
# File 'proto_docs/google/cloud/devicestreaming/v1/adb_service.rb', line 40

class DeviceMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#stream_status::Google::Cloud::DeviceStreaming::V1::StreamStatus

Returns The result of a device stream from ADB.

Note: The following fields are mutually exclusive: stream_status, status_update, stream_data. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DeviceStreaming::V1::StreamStatus)

    The result of a device stream from ADB.

    Note: The following fields are mutually exclusive: stream_status, status_update, stream_data. If a field in that set is populated, all other fields in the set will automatically be cleared.



40
41
42
43
# File 'proto_docs/google/cloud/devicestreaming/v1/adb_service.rb', line 40

class DeviceMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end