Class: Google::Cloud::DeviceStreaming::V1::DeviceSession

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/devicestreaming/v1/service.rb

Overview

Protobuf message describing the device message, used from several RPCs.

Defined Under Namespace

Modules: SessionState Classes: SessionStateEvent

Instance Attribute Summary collapse

Instance Attribute Details

#active_start_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp that the session first became ACTIVE.

Returns:



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'proto_docs/google/cloud/devicestreaming/v1/service.rb', line 152

class DeviceSession
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A message encapsulating a series of Session states and the time that the
  # DeviceSession first entered those states.
  # @!attribute [r] session_state
  #   @return [::Google::Cloud::DeviceStreaming::V1::DeviceSession::SessionState]
  #     Output only. The session_state tracked by this event
  # @!attribute [r] event_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time that the session_state first encountered that
  #     state.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. A human-readable message to explain the state.
  class SessionStateEvent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state that the DeviceSession resides.
  module SessionState
    # Default value. This value is unused.
    SESSION_STATE_UNSPECIFIED = 0

    # Initial state of a session request. The session is being validated for
    # correctness and a device is not yet requested.
    REQUESTED = 1

    # The session has been validated and is in the queue for a device.
    PENDING = 2

    # The session has been granted and the device is accepting
    # connections.
    ACTIVE = 3

    # The session duration exceeded the device's reservation time period and
    # timed out automatically.
    EXPIRED = 4

    # The user is finished with the session and it was canceled by the user
    # while the request was still getting allocated or after allocation and
    # during device usage period.
    FINISHED = 5

    # Unable to complete the session because the device was unavailable and
    # it failed to allocate through the scheduler. For example, a device not
    # in the catalog was requested or the request expired in the allocation
    # queue.
    UNAVAILABLE = 6

    # Unable to complete the session for an internal reason, such as an
    # infrastructure failure.
    ERROR = 7
  end
end

#android_device::Google::Cloud::DeviceStreaming::V1::AndroidDevice

Returns Required. The requested device.

Returns:



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'proto_docs/google/cloud/devicestreaming/v1/service.rb', line 152

class DeviceSession
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A message encapsulating a series of Session states and the time that the
  # DeviceSession first entered those states.
  # @!attribute [r] session_state
  #   @return [::Google::Cloud::DeviceStreaming::V1::DeviceSession::SessionState]
  #     Output only. The session_state tracked by this event
  # @!attribute [r] event_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time that the session_state first encountered that
  #     state.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. A human-readable message to explain the state.
  class SessionStateEvent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state that the DeviceSession resides.
  module SessionState
    # Default value. This value is unused.
    SESSION_STATE_UNSPECIFIED = 0

    # Initial state of a session request. The session is being validated for
    # correctness and a device is not yet requested.
    REQUESTED = 1

    # The session has been validated and is in the queue for a device.
    PENDING = 2

    # The session has been granted and the device is accepting
    # connections.
    ACTIVE = 3

    # The session duration exceeded the device's reservation time period and
    # timed out automatically.
    EXPIRED = 4

    # The user is finished with the session and it was canceled by the user
    # while the request was still getting allocated or after allocation and
    # during device usage period.
    FINISHED = 5

    # Unable to complete the session because the device was unavailable and
    # it failed to allocate through the scheduler. For example, a device not
    # in the catalog was requested or the request expired in the allocation
    # queue.
    UNAVAILABLE = 6

    # Unable to complete the session for an internal reason, such as an
    # infrastructure failure.
    ERROR = 7
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time that the Session was created.

Returns:



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'proto_docs/google/cloud/devicestreaming/v1/service.rb', line 152

class DeviceSession
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A message encapsulating a series of Session states and the time that the
  # DeviceSession first entered those states.
  # @!attribute [r] session_state
  #   @return [::Google::Cloud::DeviceStreaming::V1::DeviceSession::SessionState]
  #     Output only. The session_state tracked by this event
  # @!attribute [r] event_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time that the session_state first encountered that
  #     state.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. A human-readable message to explain the state.
  class SessionStateEvent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state that the DeviceSession resides.
  module SessionState
    # Default value. This value is unused.
    SESSION_STATE_UNSPECIFIED = 0

    # Initial state of a session request. The session is being validated for
    # correctness and a device is not yet requested.
    REQUESTED = 1

    # The session has been validated and is in the queue for a device.
    PENDING = 2

    # The session has been granted and the device is accepting
    # connections.
    ACTIVE = 3

    # The session duration exceeded the device's reservation time period and
    # timed out automatically.
    EXPIRED = 4

    # The user is finished with the session and it was canceled by the user
    # while the request was still getting allocated or after allocation and
    # during device usage period.
    FINISHED = 5

    # Unable to complete the session because the device was unavailable and
    # it failed to allocate through the scheduler. For example, a device not
    # in the catalog was requested or the request expired in the allocation
    # queue.
    UNAVAILABLE = 6

    # Unable to complete the session for an internal reason, such as an
    # infrastructure failure.
    ERROR = 7
  end
end

#display_name::String (readonly)

Returns Output only. The title of the DeviceSession to be presented in the UI.

Returns:

  • (::String)

    Output only. The title of the DeviceSession to be presented in the UI.



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'proto_docs/google/cloud/devicestreaming/v1/service.rb', line 152

class DeviceSession
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A message encapsulating a series of Session states and the time that the
  # DeviceSession first entered those states.
  # @!attribute [r] session_state
  #   @return [::Google::Cloud::DeviceStreaming::V1::DeviceSession::SessionState]
  #     Output only. The session_state tracked by this event
  # @!attribute [r] event_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time that the session_state first encountered that
  #     state.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. A human-readable message to explain the state.
  class SessionStateEvent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state that the DeviceSession resides.
  module SessionState
    # Default value. This value is unused.
    SESSION_STATE_UNSPECIFIED = 0

    # Initial state of a session request. The session is being validated for
    # correctness and a device is not yet requested.
    REQUESTED = 1

    # The session has been validated and is in the queue for a device.
    PENDING = 2

    # The session has been granted and the device is accepting
    # connections.
    ACTIVE = 3

    # The session duration exceeded the device's reservation time period and
    # timed out automatically.
    EXPIRED = 4

    # The user is finished with the session and it was canceled by the user
    # while the request was still getting allocated or after allocation and
    # during device usage period.
    FINISHED = 5

    # Unable to complete the session because the device was unavailable and
    # it failed to allocate through the scheduler. For example, a device not
    # in the catalog was requested or the request expired in the allocation
    # queue.
    UNAVAILABLE = 6

    # Unable to complete the session for an internal reason, such as an
    # infrastructure failure.
    ERROR = 7
  end
end

#expire_time::Google::Protobuf::Timestamp

Returns Optional. If the device is still in use at this time, any connections will be ended and the SessionState will transition from ACTIVE to FINISHED.

Note: The following fields are mutually exclusive: expire_time, ttl. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Protobuf::Timestamp)

    Optional. If the device is still in use at this time, any connections will be ended and the SessionState will transition from ACTIVE to FINISHED.

    Note: The following fields are mutually exclusive: expire_time, ttl. If a field in that set is populated, all other fields in the set will automatically be cleared.



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'proto_docs/google/cloud/devicestreaming/v1/service.rb', line 152

class DeviceSession
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A message encapsulating a series of Session states and the time that the
  # DeviceSession first entered those states.
  # @!attribute [r] session_state
  #   @return [::Google::Cloud::DeviceStreaming::V1::DeviceSession::SessionState]
  #     Output only. The session_state tracked by this event
  # @!attribute [r] event_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time that the session_state first encountered that
  #     state.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. A human-readable message to explain the state.
  class SessionStateEvent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state that the DeviceSession resides.
  module SessionState
    # Default value. This value is unused.
    SESSION_STATE_UNSPECIFIED = 0

    # Initial state of a session request. The session is being validated for
    # correctness and a device is not yet requested.
    REQUESTED = 1

    # The session has been validated and is in the queue for a device.
    PENDING = 2

    # The session has been granted and the device is accepting
    # connections.
    ACTIVE = 3

    # The session duration exceeded the device's reservation time period and
    # timed out automatically.
    EXPIRED = 4

    # The user is finished with the session and it was canceled by the user
    # while the request was still getting allocated or after allocation and
    # during device usage period.
    FINISHED = 5

    # Unable to complete the session because the device was unavailable and
    # it failed to allocate through the scheduler. For example, a device not
    # in the catalog was requested or the request expired in the allocation
    # queue.
    UNAVAILABLE = 6

    # Unable to complete the session for an internal reason, such as an
    # infrastructure failure.
    ERROR = 7
  end
end

#inactivity_timeout::Google::Protobuf::Duration (readonly)

Returns Output only. The interval of time that this device must be interacted with before it transitions from ACTIVE to TIMEOUT_INACTIVITY.

Returns:

  • (::Google::Protobuf::Duration)

    Output only. The interval of time that this device must be interacted with before it transitions from ACTIVE to TIMEOUT_INACTIVITY.



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'proto_docs/google/cloud/devicestreaming/v1/service.rb', line 152

class DeviceSession
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A message encapsulating a series of Session states and the time that the
  # DeviceSession first entered those states.
  # @!attribute [r] session_state
  #   @return [::Google::Cloud::DeviceStreaming::V1::DeviceSession::SessionState]
  #     Output only. The session_state tracked by this event
  # @!attribute [r] event_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time that the session_state first encountered that
  #     state.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. A human-readable message to explain the state.
  class SessionStateEvent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state that the DeviceSession resides.
  module SessionState
    # Default value. This value is unused.
    SESSION_STATE_UNSPECIFIED = 0

    # Initial state of a session request. The session is being validated for
    # correctness and a device is not yet requested.
    REQUESTED = 1

    # The session has been validated and is in the queue for a device.
    PENDING = 2

    # The session has been granted and the device is accepting
    # connections.
    ACTIVE = 3

    # The session duration exceeded the device's reservation time period and
    # timed out automatically.
    EXPIRED = 4

    # The user is finished with the session and it was canceled by the user
    # while the request was still getting allocated or after allocation and
    # during device usage period.
    FINISHED = 5

    # Unable to complete the session because the device was unavailable and
    # it failed to allocate through the scheduler. For example, a device not
    # in the catalog was requested or the request expired in the allocation
    # queue.
    UNAVAILABLE = 6

    # Unable to complete the session for an internal reason, such as an
    # infrastructure failure.
    ERROR = 7
  end
end

#name::String

Returns Optional. Name of the DeviceSession, e.g. "projects/{project_id}/deviceSessions/{session_id}".

Returns:

  • (::String)

    Optional. Name of the DeviceSession, e.g. "projects/{project_id}/deviceSessions/{session_id}"



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'proto_docs/google/cloud/devicestreaming/v1/service.rb', line 152

class DeviceSession
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A message encapsulating a series of Session states and the time that the
  # DeviceSession first entered those states.
  # @!attribute [r] session_state
  #   @return [::Google::Cloud::DeviceStreaming::V1::DeviceSession::SessionState]
  #     Output only. The session_state tracked by this event
  # @!attribute [r] event_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time that the session_state first encountered that
  #     state.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. A human-readable message to explain the state.
  class SessionStateEvent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state that the DeviceSession resides.
  module SessionState
    # Default value. This value is unused.
    SESSION_STATE_UNSPECIFIED = 0

    # Initial state of a session request. The session is being validated for
    # correctness and a device is not yet requested.
    REQUESTED = 1

    # The session has been validated and is in the queue for a device.
    PENDING = 2

    # The session has been granted and the device is accepting
    # connections.
    ACTIVE = 3

    # The session duration exceeded the device's reservation time period and
    # timed out automatically.
    EXPIRED = 4

    # The user is finished with the session and it was canceled by the user
    # while the request was still getting allocated or after allocation and
    # during device usage period.
    FINISHED = 5

    # Unable to complete the session because the device was unavailable and
    # it failed to allocate through the scheduler. For example, a device not
    # in the catalog was requested or the request expired in the allocation
    # queue.
    UNAVAILABLE = 6

    # Unable to complete the session for an internal reason, such as an
    # infrastructure failure.
    ERROR = 7
  end
end

#state::Google::Cloud::DeviceStreaming::V1::DeviceSession::SessionState (readonly)

Returns Output only. Current state of the DeviceSession.

Returns:



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'proto_docs/google/cloud/devicestreaming/v1/service.rb', line 152

class DeviceSession
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A message encapsulating a series of Session states and the time that the
  # DeviceSession first entered those states.
  # @!attribute [r] session_state
  #   @return [::Google::Cloud::DeviceStreaming::V1::DeviceSession::SessionState]
  #     Output only. The session_state tracked by this event
  # @!attribute [r] event_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time that the session_state first encountered that
  #     state.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. A human-readable message to explain the state.
  class SessionStateEvent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state that the DeviceSession resides.
  module SessionState
    # Default value. This value is unused.
    SESSION_STATE_UNSPECIFIED = 0

    # Initial state of a session request. The session is being validated for
    # correctness and a device is not yet requested.
    REQUESTED = 1

    # The session has been validated and is in the queue for a device.
    PENDING = 2

    # The session has been granted and the device is accepting
    # connections.
    ACTIVE = 3

    # The session duration exceeded the device's reservation time period and
    # timed out automatically.
    EXPIRED = 4

    # The user is finished with the session and it was canceled by the user
    # while the request was still getting allocated or after allocation and
    # during device usage period.
    FINISHED = 5

    # Unable to complete the session because the device was unavailable and
    # it failed to allocate through the scheduler. For example, a device not
    # in the catalog was requested or the request expired in the allocation
    # queue.
    UNAVAILABLE = 6

    # Unable to complete the session for an internal reason, such as an
    # infrastructure failure.
    ERROR = 7
  end
end

#state_histories::Array<::Google::Cloud::DeviceStreaming::V1::DeviceSession::SessionStateEvent> (readonly)

Returns Output only. The historical state transitions of the session_state message including the current session state.

Returns:



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'proto_docs/google/cloud/devicestreaming/v1/service.rb', line 152

class DeviceSession
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A message encapsulating a series of Session states and the time that the
  # DeviceSession first entered those states.
  # @!attribute [r] session_state
  #   @return [::Google::Cloud::DeviceStreaming::V1::DeviceSession::SessionState]
  #     Output only. The session_state tracked by this event
  # @!attribute [r] event_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time that the session_state first encountered that
  #     state.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. A human-readable message to explain the state.
  class SessionStateEvent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state that the DeviceSession resides.
  module SessionState
    # Default value. This value is unused.
    SESSION_STATE_UNSPECIFIED = 0

    # Initial state of a session request. The session is being validated for
    # correctness and a device is not yet requested.
    REQUESTED = 1

    # The session has been validated and is in the queue for a device.
    PENDING = 2

    # The session has been granted and the device is accepting
    # connections.
    ACTIVE = 3

    # The session duration exceeded the device's reservation time period and
    # timed out automatically.
    EXPIRED = 4

    # The user is finished with the session and it was canceled by the user
    # while the request was still getting allocated or after allocation and
    # during device usage period.
    FINISHED = 5

    # Unable to complete the session because the device was unavailable and
    # it failed to allocate through the scheduler. For example, a device not
    # in the catalog was requested or the request expired in the allocation
    # queue.
    UNAVAILABLE = 6

    # Unable to complete the session for an internal reason, such as an
    # infrastructure failure.
    ERROR = 7
  end
end

#ttl::Google::Protobuf::Duration

Returns Optional. The amount of time that a device will be initially allocated for. This can eventually be extended with the UpdateDeviceSession RPC. Default: 15 minutes.

Note: The following fields are mutually exclusive: ttl, expire_time. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Protobuf::Duration)

    Optional. The amount of time that a device will be initially allocated for. This can eventually be extended with the UpdateDeviceSession RPC. Default: 15 minutes.

    Note: The following fields are mutually exclusive: ttl, expire_time. If a field in that set is populated, all other fields in the set will automatically be cleared.



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'proto_docs/google/cloud/devicestreaming/v1/service.rb', line 152

class DeviceSession
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A message encapsulating a series of Session states and the time that the
  # DeviceSession first entered those states.
  # @!attribute [r] session_state
  #   @return [::Google::Cloud::DeviceStreaming::V1::DeviceSession::SessionState]
  #     Output only. The session_state tracked by this event
  # @!attribute [r] event_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Output only. The time that the session_state first encountered that
  #     state.
  # @!attribute [r] state_message
  #   @return [::String]
  #     Output only. A human-readable message to explain the state.
  class SessionStateEvent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The state that the DeviceSession resides.
  module SessionState
    # Default value. This value is unused.
    SESSION_STATE_UNSPECIFIED = 0

    # Initial state of a session request. The session is being validated for
    # correctness and a device is not yet requested.
    REQUESTED = 1

    # The session has been validated and is in the queue for a device.
    PENDING = 2

    # The session has been granted and the device is accepting
    # connections.
    ACTIVE = 3

    # The session duration exceeded the device's reservation time period and
    # timed out automatically.
    EXPIRED = 4

    # The user is finished with the session and it was canceled by the user
    # while the request was still getting allocated or after allocation and
    # during device usage period.
    FINISHED = 5

    # Unable to complete the session because the device was unavailable and
    # it failed to allocate through the scheduler. For example, a device not
    # in the catalog was requested or the request expired in the allocation
    # queue.
    UNAVAILABLE = 6

    # Unable to complete the session for an internal reason, such as an
    # infrastructure failure.
    ERROR = 7
  end
end