Class: Google::Cloud::DeviceStreaming::V1::ListDeviceSessionsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/devicestreaming/v1/service.rb

Overview

Response message for DirectAccessService.ListDeviceSessions.

Instance Attribute Summary collapse

Instance Attribute Details

#device_sessions::Array<::Google::Cloud::DeviceStreaming::V1::DeviceSession>

Returns The sessions matching the specified filter in the given cloud project.

Returns:



71
72
73
74
# File 'proto_docs/google/cloud/devicestreaming/v1/service.rb', line 71

class ListDeviceSessionsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



71
72
73
74
# File 'proto_docs/google/cloud/devicestreaming/v1/service.rb', line 71

class ListDeviceSessionsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end