Class: Google::Cloud::DeviceStreaming::V1::Open

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/devicestreaming/v1/adb_service.rb

Overview

Message for opening a new stream.

Instance Attribute Summary collapse

Instance Attribute Details

#service::String

Returns Optional. An ADB service to use in the new stream.

Returns:

  • (::String)

    Optional. An ADB service to use in the new stream.



145
146
147
148
# File 'proto_docs/google/cloud/devicestreaming/v1/adb_service.rb', line 145

class Open
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#stream_id::Integer

Returns Required. The unique ID that will be used to talk to this stream. This should probably just be a number that increments for each new Open request.

Returns:

  • (::Integer)

    Required. The unique ID that will be used to talk to this stream. This should probably just be a number that increments for each new Open request.



145
146
147
148
# File 'proto_docs/google/cloud/devicestreaming/v1/adb_service.rb', line 145

class Open
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end