Class: Google::Cloud::DeviceStreaming::V1::CreateDeviceSessionRequest
- Inherits:
-
Object
- Object
- Google::Cloud::DeviceStreaming::V1::CreateDeviceSessionRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/devicestreaming/v1/service.rb
Overview
Request message for DirectAccessService.CreateDeviceSession.
Instance Attribute Summary collapse
-
#device_session ⇒ ::Google::Cloud::DeviceStreaming::V1::DeviceSession
Required.
-
#device_session_id ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#device_session ⇒ ::Google::Cloud::DeviceStreaming::V1::DeviceSession
Returns Required. A DeviceSession to create.
39 40 41 42 |
# File 'proto_docs/google/cloud/devicestreaming/v1/service.rb', line 39 class CreateDeviceSessionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#device_session_id ⇒ ::String
Returns Optional. The ID to use for the DeviceSession, which will become the final component of the DeviceSession's resource name.
This value should be 4-63 characters, and valid characters are /[a-z][0-9]-/.
39 40 41 42 |
# File 'proto_docs/google/cloud/devicestreaming/v1/service.rb', line 39 class CreateDeviceSessionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The Compute Engine project under which this device will be allocated. "projects/{project_id}".
39 40 41 42 |
# File 'proto_docs/google/cloud/devicestreaming/v1/service.rb', line 39 class CreateDeviceSessionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |