Module: Google::Cloud::DeviceStreaming::V1::DeviceSession::SessionState
- Defined in:
- proto_docs/google/cloud/devicestreaming/v1/service.rb
Overview
The state that the DeviceSession resides.
Constant Summary collapse
- SESSION_STATE_UNSPECIFIED =
Default value. This value is unused.
0- REQUESTED =
Initial state of a session request. The session is being validated for correctness and a device is not yet requested.
1- PENDING =
The session has been validated and is in the queue for a device.
2- ACTIVE =
The session has been granted and the device is accepting connections.
3- EXPIRED =
The session duration exceeded the device's reservation time period and timed out automatically.
4- FINISHED =
The user is finished with the session and it was canceled by the user while the request was still getting allocated or after allocation and during device usage period.
5- UNAVAILABLE =
Unable to complete the session because the device was unavailable and it failed to allocate through the scheduler. For example, a device not in the catalog was requested or the request expired in the allocation queue.
6- ERROR =
Unable to complete the session for an internal reason, such as an infrastructure failure.
7