Class: Google::Cloud::DeviceStreaming::V1::StatusUpdate
- Inherits:
-
Object
- Object
- Google::Cloud::DeviceStreaming::V1::StatusUpdate
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/devicestreaming/v1/adb_service.rb
Overview
A StatusUpdate message given over the ADB protocol for the device state.
Defined Under Namespace
Modules: DeviceState Classes: PropertiesEntry
Instance Attribute Summary collapse
-
#features ⇒ ::String
A comma-separated list of "features" that this device supports.
-
#properties ⇒ ::Google::Protobuf::Map{::String => ::String}
A map of properties with information about this device.
-
#state ⇒ ::Google::Cloud::DeviceStreaming::V1::StatusUpdate::DeviceState
The device's state.
Instance Attribute Details
#features ⇒ ::String
Returns A comma-separated list of "features" that this device supports.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'proto_docs/google/cloud/devicestreaming/v1/adb_service.rb', line 71 class StatusUpdate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class PropertiesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state displayed with the ADB Device when running "adb devices" module DeviceState # The device state is unknown. DEVICE_STATE_UNSPECIFIED = 0 # The ADB device is in the "device" status. DEVICE = 1 # The ADB device is in the "recovery" status. RECOVERY = 2 # The ADB device is in the "rescue" status. RESCUE = 3 # The ADB device is in the "sideload" status. SIDELOAD = 4 # The ADB device is in the "missing" status. MISSING = 10 # The ADB device is in the "offline" status. OFFLINE = 11 # The ADB device is in the "unauthorized" status. UNAUTHORIZED = 12 # The ADB device is in the "authorizing" status. AUTHORIZING = 13 # The ADB device is in the "connecting" status. CONNECTING = 14 end end |
#properties ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns A map of properties with information about this device.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'proto_docs/google/cloud/devicestreaming/v1/adb_service.rb', line 71 class StatusUpdate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class PropertiesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state displayed with the ADB Device when running "adb devices" module DeviceState # The device state is unknown. DEVICE_STATE_UNSPECIFIED = 0 # The ADB device is in the "device" status. DEVICE = 1 # The ADB device is in the "recovery" status. RECOVERY = 2 # The ADB device is in the "rescue" status. RESCUE = 3 # The ADB device is in the "sideload" status. SIDELOAD = 4 # The ADB device is in the "missing" status. MISSING = 10 # The ADB device is in the "offline" status. OFFLINE = 11 # The ADB device is in the "unauthorized" status. UNAUTHORIZED = 12 # The ADB device is in the "authorizing" status. AUTHORIZING = 13 # The ADB device is in the "connecting" status. CONNECTING = 14 end end |
#state ⇒ ::Google::Cloud::DeviceStreaming::V1::StatusUpdate::DeviceState
Returns The device's state.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'proto_docs/google/cloud/devicestreaming/v1/adb_service.rb', line 71 class StatusUpdate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class PropertiesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The state displayed with the ADB Device when running "adb devices" module DeviceState # The device state is unknown. DEVICE_STATE_UNSPECIFIED = 0 # The ADB device is in the "device" status. DEVICE = 1 # The ADB device is in the "recovery" status. RECOVERY = 2 # The ADB device is in the "rescue" status. RESCUE = 3 # The ADB device is in the "sideload" status. SIDELOAD = 4 # The ADB device is in the "missing" status. MISSING = 10 # The ADB device is in the "offline" status. OFFLINE = 11 # The ADB device is in the "unauthorized" status. UNAUTHORIZED = 12 # The ADB device is in the "authorizing" status. AUTHORIZING = 13 # The ADB device is in the "connecting" status. CONNECTING = 14 end end |